pyGARL stands for *Python Gesture Analysis and Recognition Library* and, as you may expect, it's used to build gesture recognition systems.

All the documentation and project info can be found here: https://github.com/federico-terzi/pygarl
